package cn.aid.apiweb.controller;

import cn.aid.apiweb.assist.resolver.RequestHeader;
import cn.aid.apiweb.entity.GlobalHeader;
import cn.aid.apiweb.service.user.UserService;
import cn.aid.common.utils.api.model.APIResult;
import cn.aid.common.utils.util.HttpUtil;
import cn.aid.data.api.app.dto.DeviceLoginDTO;
import cn.aid.data.api.app.dto.LoginInfoDTO;
import cn.aid.data.api.app.vo.UserInfoVo;
import eu.bitwalker.useragentutils.Browser;
import eu.bitwalker.useragentutils.OperatingSystem;
import eu.bitwalker.useragentutils.UserAgent;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import javax.validation.Valid;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@Slf4j
@RestController
@RequestMapping(value = "/token")
public class LoginController
{

    @Autowired
    private UserService userService;

    @RequestMapping(method = RequestMethod.POST)
    public APIResult<UserInfoVo> login(HttpServletRequest request, @Valid @RequestBody LoginInfoDTO loginInfoDTO)
    {

        String terminal = request.getHeader("terminal");
        String merchant = request.getHeader("merchant");
        String userAgent = request.getHeader("User-Agent");

        String ip = HttpUtil.getClientIp(request);
        loginInfoDTO.setIp(ip);
        loginInfoDTO.setTerminal(terminal);
        loginInfoDTO.setMerchant(merchant);

        log.info("login request header : ip={},terminal={},merchant={},user-agent={}", ip, terminal, merchant);
        return userService.login(loginInfoDTO);
    }

    @RequestMapping(method = RequestMethod.PUT)
    public APIResult<UserInfoVo> refresh(HttpServletRequest request, @RequestBody DeviceLoginDTO deviceLoginDTO)
    {
        String deviceCode = deviceLoginDTO.getDeviceCode();
        String merchant = request.getHeader("merchant");
        log.info("refresh request header : deviceCode={}, merchant={}", deviceCode, merchant);
        return userService.refresh(deviceCode, merchant, Boolean.TRUE);
    }

    @RequestMapping(method = RequestMethod.DELETE)
    public APIResult<Boolean> logout(@RequestHeader GlobalHeader globalHeader)
    {
        String userId = globalHeader.getUid();
        return userService.logout(userId);
    }


}
