package cn.aid.apiweb.service.user;

import cn.aid.apiweb.code.ApiWebCode;
import cn.aid.common.utils.api.model.APIResult;
import cn.aid.common.utils.api.page.Page;
import cn.aid.data.api.user.dto.TerminalDeviceDTO;
import cn.aid.data.api.user.dto.UserDeviceDTO;
import cn.aid.data.api.user.vo.TerminalDeviceVo;
import cn.aid.data.api.user.vo.TerminalUserVo;
import cn.aid.data.api.user.vo.WhiteUserVo;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@FeignClient(name = "${service.user.name}", fallback = UserClient.UserServiceHystrix.class)
public interface UserClient
{

    @RequestMapping(value = "/user/code/{code}", method = RequestMethod.GET)
    APIResult<TerminalUserVo> loadUserByEid(@PathVariable("code") String code);

    @RequestMapping(value = "/user/{id}", method = RequestMethod.GET)
    APIResult<TerminalUserVo> findUserById(@PathVariable("id") String id);

    @RequestMapping(value = "/device/bind", method = RequestMethod.POST)
    APIResult<TerminalDeviceVo> deviceBind(@RequestBody TerminalDeviceDTO terminalDeviceDTO);

    @RequestMapping(value = "/device/unbind", method = RequestMethod.DELETE)
    APIResult<Boolean> deviceUnbind(@RequestParam("userId") String userId);

    @RequestMapping(value = "/device/uid/{uid}", method = RequestMethod.GET)
    APIResult<TerminalDeviceVo> findDeviceByUid(@PathVariable("userId") String uid);

    @RequestMapping(value = "/device/deviceCode/{deviceCode}", method = RequestMethod.GET)
    List<TerminalDeviceVo> findByDeviceCode(@PathVariable("deviceCode") String deviceCode);

    @RequestMapping(value = "/white/user/{userId}", method = RequestMethod.GET)
    APIResult<WhiteUserVo> findWhiteUserById(@PathVariable("userId") String userId);

    @RequestMapping(value = "/device/updatebind", method = RequestMethod.PUT)
    APIResult updateDeviceBind(TerminalDeviceDTO deviceDTO);

    @RequestMapping(value = "/userDevice/op/{uid}", method = RequestMethod.GET)
    int opUserDevice(@PathVariable("uid") String uid,
                     @RequestBody UserDeviceDTO userDeviceDTO);

    @Component
    class UserServiceHystrix implements UserClient
    {

        @Override
        public APIResult loadUserByEid(String code)
        {
            return APIResult.error(ApiWebCode.SERVER_ERROR);
        }

        @Override
        public APIResult deviceBind(TerminalDeviceDTO terminalDeviceDTO)
        {
            return APIResult.error(ApiWebCode.SERVER_ERROR);
        }

        @Override
        public APIResult deviceUnbind(String userId)
        {
            return APIResult.error(ApiWebCode.SERVER_ERROR);
        }

        @Override
        public APIResult findDeviceByUid(String uid)
        {
            return APIResult.error(ApiWebCode.SERVER_ERROR);
        }

        @Override
        public APIResult findUserById(String id)
        {
            return APIResult.error(ApiWebCode.SERVER_ERROR);
        }

        @Override
        public List<TerminalDeviceVo> findByDeviceCode(String deviceCode)
        {
            return null;
        }

        @Override
        public APIResult<WhiteUserVo> findWhiteUserById(String userId)
        {
            return APIResult.error(ApiWebCode.SERVER_ERROR);
        }

        @Override
        public APIResult updateDeviceBind(TerminalDeviceDTO deviceDTO)
        {
            return APIResult.error(ApiWebCode.SERVER_ERROR);
        }

        @Override
        public int opUserDevice(String uid, UserDeviceDTO userDeviceDTO)
        {
            return 0;
        }

    }
}
