package cn.aid.cmsweb.controller.user;

import cn.aid.cmsweb.assist.resolver.NeedUser;
import cn.aid.cmsweb.entity.UserDetails;
import cn.aid.cmsweb.service.user.TerminalUserService;
import cn.aid.common.utils.api.model.APICode;
import cn.aid.common.utils.api.model.APIResult;
import cn.aid.common.utils.api.page.Page;
import cn.aid.data.api.auth.dto.AuthDTO;
import cn.aid.data.api.user.dto.TerminalUserDTO;
import cn.aid.data.api.user.dto.TerminalUserSearchDTO;
import cn.aid.common.utils.util.BeanUtil;
import cn.aid.data.api.user.vo.TerminalUserAuthVo;
import cn.aid.data.api.user.vo.TerminalUserVo;
import com.alibaba.fastjson.JSON;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Slf4j
@RestController
@RequestMapping(value = "/user")
public class TerminalUserController {

    @Autowired
    private TerminalUserService terminalUserService;



    @RequestMapping(value = "/list", method = RequestMethod.GET)
    public APIResult<Page<TerminalUserVo>> search(@NeedUser UserDetails user, TerminalUserSearchDTO searchDTO) {
        log.info("/list request params ,params = {}",JSON.toJSONString(searchDTO));

        if (!user.isPlatForm()) {
            String merchantId = user.getMerchantId();
            searchDTO.setMerchantId(merchantId);
        }

        return terminalUserService.search(BeanUtil.convertToMap(searchDTO));
    }

    @RequestMapping(method = RequestMethod.POST)
    public APIResult<TerminalUserVo> create(@RequestBody TerminalUserDTO terminalUserDTO) {
        return terminalUserService.create(terminalUserDTO);
    }

    @RequestMapping(method = RequestMethod.PUT)
    public APIResult<TerminalUserVo> update(@RequestBody TerminalUserDTO terminalUserDTO) {
        return terminalUserService.update(terminalUserDTO);
    }

    @RequestMapping(value = "/{id}", method = RequestMethod.DELETE)
    public APIResult<Boolean> delete(@PathVariable("id") String id) {
        return terminalUserService.delete(id);
    }

    @RequestMapping(value = "/{id}", method = RequestMethod.GET)
    public APIResult<TerminalUserVo> getUser(@PathVariable("id") String id) {
        return terminalUserService.getUser(id);
    }

    @RequestMapping(value = "/auth", method = RequestMethod.POST)
    public APIResult updateAuth(@RequestBody AuthDTO dto) {
        if(StringUtils.isBlank(dto.getId())){
            log.info("update Auth error ! id is empty");
            return APIResult.error(APICode.PARAMETER_ERROR);
        }
        return terminalUserService.saveOrUpdateAuth(dto);
    }

    @RequestMapping(value = "/auth/list", method = RequestMethod.GET)
    public APIResult<Page<TerminalUserAuthVo>> findAuthList(TerminalUserSearchDTO searchDTO) {
        log.info("/auth/list request params ,params = {}",JSON.toJSONString(searchDTO));


        Page<TerminalUserAuthVo> authVoPage = terminalUserService.findAuthList(BeanUtil.convertToMap(searchDTO));

        List<TerminalUserAuthVo> terminalUserAuthVos = authVoPage.getList();

        return APIResult.ok(authVoPage);
    }



}
