package cn.aid.resourceservice.controller;

import cn.aid.common.utils.api.model.APICode;
import cn.aid.common.utils.api.model.APIResult;
import cn.aid.common.utils.api.page.Page;
import cn.aid.common.utils.constant.ResourceType;
import cn.aid.common.utils.dto.resource.ResourceSearchDTO;
import cn.aid.data.api.resource.entity.Resource;
import cn.aid.resourceservice.service.ResourceService;
import com.alibaba.fastjson.JSON;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

@Slf4j
@RestController
@RequestMapping(value = "resource")
public class ResourceController {

    @Autowired
    private ResourceService resourceService;

    public static String HTTP_VIDEO_DOMAIN = "http://efunvideo.ai160.com";
    public static String LJ_VIDEO_DOMAIN = "http://ljvideo.ai160.com";

    public static String HTTPS_VIDEO_DOMAIN = "https://efunvideo.ai160.com";

    @RequestMapping(value = "/list")
    public APIResult<Page<Resource>> search(ResourceSearchDTO resourceSearchDTO) {
        log.info(JSON.toJSONString(resourceSearchDTO));

        // 参数错误返回
        if (resourceSearchDTO == null || resourceSearchDTO.getType() == null) {
            return APIResult.error(APICode.PARAMETER_ERROR);
        }

        Integer type = resourceSearchDTO.getType();
        if (type.intValue() == ResourceType.IMG || type.intValue() == ResourceType.AUDIO) {
            // 图片本地取
            Resource resource = new Resource();

            resource.setType(type);
            String code = resourceSearchDTO.getCode();
            if (!StringUtils.isEmpty(code)) {
                resource.setCode("%" + code.trim() + "%");
            }

            String name = resourceSearchDTO.getName();
            if (!StringUtils.isEmpty(name)) {
                resource.setName("%" + name.trim() + "%");
            }
            return resourceService.search(resource, resourceSearchDTO.getPageNo(), resourceSearchDTO.getPageSize());
        }else {
            // 其他去云平台

                return null;
        }
    }



    @RequestMapping(method = RequestMethod.POST)
    public APIResult<Resource> create(@RequestBody Resource resource) {


        if(resource.getType().intValue() == ResourceType.VIDEO){
            //视频类型   存远程资源库
            return  resourceService.saveRemoteResource(resource);
        }else {
            if (StringUtils.isEmpty(resource.getCode()) || StringUtils.isEmpty(resource.getPath())) {
                return APIResult.error(APICode.PARAMETER_ERROR);
            }

            if (resourceService.exists(resource.getCode())) {
                return APIResult.error(APICode.ALREADY_EXISTS);
            }

            //图片类型  存本地
            Resource result = resourceService.save(resource);
            return APIResult.ok(result);
        }

    }

    @RequestMapping(value = "/batch", method = RequestMethod.GET)
    public APIResult<Map<String, Resource>> getBatch(@RequestParam("id") List<String> ids) {
        return resourceService.findMixByIds(ids);
    }

    @RequestMapping(value="/{id}", method = RequestMethod.PUT)
    public APIResult<Resource> update(@PathVariable("id") String id, @RequestBody Resource resource) {
        if(resource.getType().intValue() == ResourceType.VIDEO){
            //视频类型   存远程资源库
            return  resourceService.updateRemoteResource(resource);
        }else{
            resourceService.update(resource);
        }

        return APIResult.ok();
    }

}
