package cn.aid.userservice.controller;

import cn.aid.common.utils.api.model.APIResult;
import cn.aid.common.utils.api.page.Page;
import cn.aid.common.utils.enums.BaseOrderEnum;
import cn.aid.common.utils.enums.BaseStatusEnum;
import cn.aid.data.api.user.dto.TerminalUserSearchDTO;
import cn.aid.data.api.user.entity.TerminalUser;
import cn.aid.userservice.code.UserServiceAPICode;
import cn.aid.userservice.service.MerchantService;
import cn.aid.userservice.service.TerminalDeviceService;
import cn.aid.userservice.service.TerminalUserService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.LinkedHashMap;
import java.util.List;

@Slf4j
@RestController
@RequestMapping(value = "/user")
public class TerminalUserController {

    @Autowired
    private TerminalUserService terminalUserService;


    @Autowired
    private MerchantService merchantService;



    @Autowired
    private TerminalDeviceService terminalDeviceService;

    @RequestMapping(value = "/list", method = RequestMethod.GET)
    public APIResult<Page<TerminalUser>> search(TerminalUserSearchDTO terminalUserSearchDTO) {
        TerminalUser terminalUser = new TerminalUser();

        String code = terminalUserSearchDTO.getCode();
        String campusId = terminalUserSearchDTO.getCampusId();
        if (!StringUtils.isEmpty(code)) {
            terminalUser.setCode("%" + code + "%");
        }else if (!StringUtils.isEmpty(campusId)) {
            terminalUser.setCampusId(campusId);
        }

        String merchantId = terminalUserSearchDTO.getMerchantId();
        if (!StringUtils.isEmpty(merchantId)) {
            terminalUser.setMerchantId(merchantId);
        }

        BaseStatusEnum status = terminalUserSearchDTO.getStatus();
        if (status != null) {
            terminalUser.setStatus(status);
        }

        LinkedHashMap<String, BaseOrderEnum> sort = new LinkedHashMap<>();
        sort.put("gmtModified", BaseOrderEnum.DESC);

        APIResult<Page<TerminalUser>> result = terminalUserService.search(terminalUser, terminalUserSearchDTO.getPageNo(), terminalUserSearchDTO.getPageSize(), sort);
        if (result.getSuccess()) {
            List<TerminalUser> terminalUserList = result.getData().getList();
        }

        return result;
    }


    @RequestMapping(method = RequestMethod.GET)
    public APIResult<List<TerminalUser>> findByCondition(TerminalUserSearchDTO terminalUserSearchDTO) {
        TerminalUser terminalUser = new TerminalUser();

        String code = terminalUserSearchDTO.getCode();
        String campusId = terminalUserSearchDTO.getCampusId();
        if (!StringUtils.isEmpty(code)) {
            terminalUser.setCode("%" + code + "%");
        } else if (!StringUtils.isEmpty(campusId)) {
            terminalUser.setCampusId(campusId);
        }

        String merchantId = terminalUserSearchDTO.getMerchantId();
        if (!StringUtils.isEmpty(merchantId)) {
            terminalUser.setMerchantId(merchantId);
        }

        LinkedHashMap<String, BaseOrderEnum> sort = new LinkedHashMap<>();
        sort.put("gmtModified", BaseOrderEnum.DESC);

        List<TerminalUser> terminalUserList = terminalUserService.find(terminalUser, sort);
        return APIResult.ok(terminalUserList);
    }




    @RequestMapping(value = "/{id}", method = RequestMethod.GET)
    public APIResult<TerminalUser> getUser(@PathVariable("id") String id) {
        TerminalUser terminalUser = terminalUserService.find(id);
        if (terminalUser == null) {
            return APIResult.error(UserServiceAPICode.NOT_EXISTS);
        }

        return APIResult.ok(terminalUser);
    }

    @RequestMapping(value = "/code/{code}", method = RequestMethod.GET)
    public APIResult<TerminalUser> loadUser(@PathVariable("code") String code) {
        TerminalUser terminalUser = terminalUserService.loadUserByCode(code);
        if (terminalUser == null) {
            return APIResult.error(UserServiceAPICode.NOT_EXISTS);
        }

        return APIResult.ok(terminalUser);
    }

    @RequestMapping(value = "/campus/ids", method = RequestMethod.GET)
    public APIResult<List<TerminalUser>> findByCampusIds(@RequestParam("id") List<String> campusIds) {
        List<TerminalUser> terminalUserList = terminalUserService.findByCampusIds(campusIds);
        return APIResult.ok(terminalUserList);
    }

    @RequestMapping(value = "/ids", method = RequestMethod.GET)
    public APIResult<List<TerminalUser>> findByIds(@RequestParam("id") List<String> ids) {
        List<TerminalUser> terminalUserList = terminalUserService.findByIds(ids);
        return APIResult.ok(terminalUserList);
    }

    // 禁用终端用户
    @RequestMapping(value = "/{id}", method = RequestMethod.DELETE)
    public APIResult<Boolean> delete(@PathVariable("id") String id) {
        return terminalUserService.delete(id);
    }


}
