package cn.aid.userservice.service;

import cn.aid.common.utils.api.model.APIResult;
import cn.aid.common.utils.api.page.Page;
import cn.aid.data.api.user.dto.CmsUserDTO;
import cn.aid.common.utils.enums.BaseOrderEnum;
import cn.aid.common.utils.enums.BaseStatusEnum;
import cn.aid.common.utils.util.JpaSortUtil;
import cn.aid.data.api.user.entity.CmsUser;
import cn.aid.data.api.user.entity.Merchant;
import cn.aid.userservice.code.UserServiceAPICode;
import cn.aid.userservice.repository.CmsUserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.transaction.Transactional;
import java.util.*;

import static cn.aid.userservice.utils.DTOConverter.convert;


@Service
public class CmsUserService {

    @Autowired
    private CmsUserRepository cmsUserRepository;

    @Autowired
    private MerchantService merchantService;

    public List<CmsUser> findMerchantAdminList(String merchantId) {
        CmsUser cmsUser = new CmsUser();
        cmsUser.setIsAdmin(Boolean.TRUE);
        cmsUser.setMerchantId(merchantId);
        cmsUser.setStatus(BaseStatusEnum.NORMAL);
        return cmsUserRepository.find(cmsUser);
    }

    public APIResult<CmsUser> loadCmsUser(String userName) {
        CmsUser cmsUser = cmsUserRepository.findByNameAndStatus(userName, BaseStatusEnum.NORMAL);
        if (cmsUser == null) {
            return APIResult.error(UserServiceAPICode.NOT_EXISTS);
        }

        return APIResult.ok(cmsUser);
    }

    public APIResult<Page<CmsUser>> search(CmsUser user, Integer pageNo, Integer pageSize, LinkedHashMap<String, BaseOrderEnum> sort) {
        Long count = cmsUserRepository.count(user);
        Page<CmsUser> page = new Page<>(count, pageNo, pageSize);
        if (count == 0) {
            return APIResult.ok(page);
        }

        List<CmsUser> userList = cmsUserRepository.find(user, page.getStart(), pageSize, JpaSortUtil.sort(sort));
        page.setList(userList);

        return APIResult.ok(page);
    }

    @Transactional
    public APIResult<CmsUser> create(CmsUserDTO userDTO) {
        CmsUser user = convert(userDTO);
        String merchantId = user.getMerchantId();
        Merchant merchant = merchantService.findOne(merchantId);
        if (merchant == null) {
            return APIResult.error(UserServiceAPICode.NOT_EXISTS);
        }
        user.setDomain(merchant.getDomain());
        CmsUser result = cmsUserRepository.save(user);
        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<CmsUser> update(CmsUserDTO userDTO) {
        CmsUser user = convert(userDTO);
        CmsUser result = cmsUserRepository.update(user);
        return APIResult.ok(result);
    }

    @Transactional
    public APIResult<Boolean> delete(String id) {
        Integer count = cmsUserRepository.updateStatusById(id, BaseStatusEnum.DISABLE);
        if (count == 0) {
            return APIResult.error(UserServiceAPICode.NOT_EXISTS);
        }

        return APIResult.ok(true);
    }
}
