package cn.aid.userservice.service;

import cn.aid.common.utils.api.page.Page;
import cn.aid.common.utils.enums.BaseOrderEnum;
import cn.aid.common.utils.enums.BaseStatusEnum;
import cn.aid.common.utils.util.JpaSortUtil;
import cn.aid.data.api.user.dto.WhiteUserDTO;
import cn.aid.data.api.user.entity.WhiteUser;
import cn.aid.userservice.repository.WhiteUserRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.transaction.Transactional;
import java.util.LinkedHashMap;
import java.util.List;

import static cn.aid.userservice.utils.DTOConverter.convert;

@Service
public class WhiteUserService {

    @Autowired
    private WhiteUserRepository whiteUserRepository;

    @Transactional
    public WhiteUser addUser(WhiteUserDTO whiteUserDTO) {
        WhiteUser whiteUser = convert(whiteUserDTO);
        WhiteUser result = whiteUserRepository.save(whiteUser);
        return result;
    }

    @Transactional
    public WhiteUser updateUser(WhiteUserDTO whiteUserDTO) {
        WhiteUser whiteUser = convert(whiteUserDTO);
        return whiteUserRepository.update(whiteUser);
    }

    public WhiteUser findUserByUserId(String userId) {
        return whiteUserRepository.findFirstByUserIdAndAndStatus(userId, BaseStatusEnum.NORMAL);
    }

    public Page<WhiteUser> search(WhiteUser whiteUser, Integer pageNo, Integer pageSize, LinkedHashMap<String, BaseOrderEnum> sort) {
        Long count = whiteUserRepository.count(whiteUser);
        Page<WhiteUser> page = new Page(count, pageNo, pageSize);
        if (count == 0) {
            return page;
        }
        List<WhiteUser> whiteUserList = whiteUserRepository.find(whiteUser, page.getStart(), pageSize, JpaSortUtil.sort(sort));
        page.setList(whiteUserList);
        return page;
    }

    @Transactional
    public Boolean deleteUser(String userId) {
        Integer count = whiteUserRepository.deleteByUserId(userId);
        return count > 0;
    }
}
